#
#    Copyright 2024 OpenAI
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.

from __future__ import annotations

from typing import Union

from .chat_completion_assistant_message_param import ChatCompletionAssistantMessageParam
from .chat_completion_function_message_param import ChatCompletionFunctionMessageParam
from .chat_completion_system_message_param import ChatCompletionSystemMessageParam
from .chat_completion_tool_message_param import ChatCompletionToolMessageParam
from .chat_completion_user_message_param import ChatCompletionUserMessageParam

__all__ = ["ChatCompletionMessageParam"]

ChatCompletionMessageParam = Union[
    ChatCompletionSystemMessageParam,
    ChatCompletionUserMessageParam,
    ChatCompletionAssistantMessageParam,
    ChatCompletionToolMessageParam,
    ChatCompletionFunctionMessageParam,
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/build.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2
from _qwak_proto.qwak.fitness_service import fitness_pb2 as qwak_dot_fitness__service_dot_fitness__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17qwak/builds/build.proto\x12\x18qwak.builds.orchestrator\x1a/qwak/user_application/common/v0/resources.proto\x1a\"qwak/fitness_service/fitness.proto\"\xec\x05\n\x0fRemoteBuildSpec\x12\x43\n\x10\x62uild_properties\x18\x01 \x01(\x0b\x32).qwak.builds.orchestrator.BuildProperties\x12\x35\n\tbuild_env\x18\x02 \x01(\x0b\x32\".qwak.builds.orchestrator.BuildEnv\x12\x43\n\rcpu_resources\x18\x03 \x01(\x0b\x32&.qwak.builds.orchestrator.CpuResourcesB\x02\x18\x01H\x00\x12\x43\n\rgpu_resources\x18\x07 \x01(\x0b\x32&.qwak.builds.orchestrator.GpuResourcesB\x02\x18\x01H\x00\x12\x62\n\x1c\x63lient_pod_compute_resources\x18\r \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResourcesH\x00\x12\x0f\n\x07verbose\x18\x04 \x01(\x05\x12\x17\n\x0f\x62uild_code_path\x18\x05 \x01(\t\x12\x14\n\x0c\x62uild_config\x18\x06 \x01(\t\x12\x15\n\rbuild_v1_flag\x18\x08 \x01(\x08\x12H\n\x13\x62uild_properties_v1\x18\t \x01(\x0b\x32+.qwak.builds.orchestrator.BuildPropertiesV1\x12\x13\n\x0b\x62uild_steps\x18\n \x03(\t\x12\x16\n\x0e\x65nvironment_id\x18\x0b \x01(\t\x12\x13\n\x0bsdk_version\x18\x0c \x01(\t\x12=\n\x0fpurchase_option\x18\x0e \x01(\x0e\x32$.qwak.fitness.service.PurchaseOption\x12\x1c\n\x14\x62uild_destined_image\x18\x0f \x01(\t\x12\"\n\x1aprovision_instance_timeout\x18\x10 \x01(\x05\x42\x0b\n\tResources\"g\n\x11\x42uildPropertiesV1\x12\x18\n\x10\x62uild_config_url\x18\x01 \x01(\t\x12\x1a\n\x12qwak_sdk_wheel_url\x18\x02 \x01(\t\x12\x1c\n\x14qwak_sdk_version_url\x18\x03 \x01(\t\"\xa6\x01\n\x0f\x42uildProperties\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x39\n\tmodel_uri\x18\x05 \x01(\x0b\x32&.qwak.builds.orchestrator.ModelUriSpec\x12\x16\n\x0egpu_compatible\x18\x06 \x01(\x08\"\xb2\x01\n\x0cModelUriSpec\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x17\n\x0fgit_credentials\x18\x03 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x04 \x01(\t\x12\x11\n\tcommit_id\x18\x05 \x01(\t\x12\x10\n\x08main_dir\x18\x06 \x01(\t\x12#\n\x1b\x64\x65pendency_required_folders\x18\x07 \x03(\t\"|\n\x08\x42uildEnv\x12\x37\n\ndocker_env\x18\x01 \x01(\x0b\x32#.qwak.builds.orchestrator.DockerEnv\x12\x37\n\npython_env\x18\x02 \x01(\x0b\x32#.qwak.builds.orchestrator.PythonEnv\"\x8a\x01\n\tDockerEnv\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x10\n\x08\x65nv_vars\x18\x02 \x03(\t\x12\x10\n\x08no_cache\x18\x03 \x01(\x08\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x04 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x05 \x01(\t\"|\n\tPythonEnv\x12\x17\n\x0fgit_credentials\x18\x01 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x02 \x01(\t\x12\x18\n\x10qwak_sdk_version\x18\x03 \x01(\t\x12\x1c\n\x14qwak_sdk_extra_index\x18\x04 \x01(\t\"n\n\x0c\x43puResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x02\x12\x15\n\rmemory_amount\x18\x02 \x01(\x05\x12:\n\x0cmemory_units\x18\x03 \x01(\x0e\x32$.qwak.builds.orchestrator.MemoryUnit\"W\n\x0cGpuResources\x12\x33\n\x08gpu_type\x18\x01 \x01(\x0e\x32!.qwak.builds.orchestrator.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05\"\x91\x01\n\x13\x44\x61taTableDefinition\x12?\n\x07\x63olumns\x18\x01 \x03(\x0b\x32..qwak.builds.orchestrator.DataColumnDefinition\x12\x39\n\x0b\x64\x61ta_format\x18\x02 \x01(\x0b\x32$.qwak.builds.orchestrator.DataFormat\"\\\n\x14\x44\x61taColumnDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x04type\x18\x02 \x01(\x0e\x32(.qwak.builds.orchestrator.DataColumnType\"J\n\nDataFormat\x12\x32\n\x03\x63sv\x18\x01 \x01(\x0b\x32#.qwak.builds.orchestrator.CsvFormatH\x00\x42\x08\n\x06\x66ormat\"G\n\tCsvFormat\x12\x11\n\tdelimiter\x18\x01 \x01(\t\x12\x12\n\nquote_char\x18\x02 \x01(\t\x12\x13\n\x0b\x65scape_char\x18\x03 \x01(\t\"\xa5\x01\n\x0e\x42uildInitiator\x12<\n\x04user\x18\x01 \x01(\x0b\x32,.qwak.builds.orchestrator.UserBuildInitiatorH\x00\x12H\n\nautomation\x18\x02 \x01(\x0b\x32\x32.qwak.builds.orchestrator.AutomationBuildInitiatorH\x00\x42\x0b\n\tInitiator\"\x14\n\x12UserBuildInitiator\"`\n\x18\x41utomationBuildInitiator\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61utomation_name\x18\x03 \x01(\t*7\n\nMemoryUnit\x12\x17\n\x13UNKNOWN_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x8c\x02\n\x07GpuType\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x12\x14\n\x10NVIDIA_T4_1_4_15\x10\x07\x12\x14\n\x10NVIDIA_T4_1_8_30\x10\x08\x12\x15\n\x11NVIDIA_T4_1_16_60\x10\t\x12\x1e\n\x1aNVIDIA_A100_80GB_8_96_1360\x10\n\x12\x16\n\x12NVIDIA_V100_1_8_52\x10\x0b\x12\x18\n\x14NVIDIA_V100_4_32_208\x10\x0c*d\n\x0e\x44\x61taColumnType\x12\x17\n\x13INVALID_COLUMN_TYPE\x10\x00\x12\n\n\x06OBJECT\x10\x01\x12\x07\n\x03INT\x10\x02\x12\t\n\x05\x46LOAT\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\x0c\n\x08\x44\x41TETIME\x10\x05*K\n\x13\x42\x61seDockerImageType\x12\"\n\x1eUNKNOWN_BASE_DOCKER_IMAGE_TYPE\x10\x00\x12\x07\n\x03\x43PU\x10\x01\x12\x07\n\x03GPU\x10\x02\x42\'\n#com.qwak.ai.builds.orchestrator.apiP\x01\x62\x06proto3')

_MEMORYUNIT = DESCRIPTOR.enum_types_by_name['MemoryUnit']
MemoryUnit = enum_type_wrapper.EnumTypeWrapper(_MEMORYUNIT)
_GPUTYPE = DESCRIPTOR.enum_types_by_name['GpuType']
GpuType = enum_type_wrapper.EnumTypeWrapper(_GPUTYPE)
_DATACOLUMNTYPE = DESCRIPTOR.enum_types_by_name['DataColumnType']
DataColumnType = enum_type_wrapper.EnumTypeWrapper(_DATACOLUMNTYPE)
_BASEDOCKERIMAGETYPE = DESCRIPTOR.enum_types_by_name['BaseDockerImageType']
BaseDockerImageType = enum_type_wrapper.EnumTypeWrapper(_BASEDOCKERIMAGETYPE)
UNKNOWN_MEMORY_UNIT = 0
MIB = 1
GIB = 2
INVALID = 0
NVIDIA_K80 = 1
NVIDIA_V100 = 2
NVIDIA_A100 = 3
NVIDIA_T4 = 4
NVIDIA_A10G = 5
NVIDIA_L4 = 6
NVIDIA_T4_1_4_15 = 7
NVIDIA_T4_1_8_30 = 8
NVIDIA_T4_1_16_60 = 9
NVIDIA_A100_80GB_8_96_1360 = 10
NVIDIA_V100_1_8_52 = 11
NVIDIA_V100_4_32_208 = 12
INVALID_COLUMN_TYPE = 0
OBJECT = 1
INT = 2
FLOAT = 3
BOOLEAN = 4
DATETIME = 5
UNKNOWN_BASE_DOCKER_IMAGE_TYPE = 0
CPU = 1
GPU = 2


_REMOTEBUILDSPEC = DESCRIPTOR.message_types_by_name['RemoteBuildSpec']
_BUILDPROPERTIESV1 = DESCRIPTOR.message_types_by_name['BuildPropertiesV1']
_BUILDPROPERTIES = DESCRIPTOR.message_types_by_name['BuildProperties']
_MODELURISPEC = DESCRIPTOR.message_types_by_name['ModelUriSpec']
_BUILDENV = DESCRIPTOR.message_types_by_name['BuildEnv']
_DOCKERENV = DESCRIPTOR.message_types_by_name['DockerEnv']
_PYTHONENV = DESCRIPTOR.message_types_by_name['PythonEnv']
_CPURESOURCES = DESCRIPTOR.message_types_by_name['CpuResources']
_GPURESOURCES = DESCRIPTOR.message_types_by_name['GpuResources']
_DATATABLEDEFINITION = DESCRIPTOR.message_types_by_name['DataTableDefinition']
_DATACOLUMNDEFINITION = DESCRIPTOR.message_types_by_name['DataColumnDefinition']
_DATAFORMAT = DESCRIPTOR.message_types_by_name['DataFormat']
_CSVFORMAT = DESCRIPTOR.message_types_by_name['CsvFormat']
_BUILDINITIATOR = DESCRIPTOR.message_types_by_name['BuildInitiator']
_USERBUILDINITIATOR = DESCRIPTOR.message_types_by_name['UserBuildInitiator']
_AUTOMATIONBUILDINITIATOR = DESCRIPTOR.message_types_by_name['AutomationBuildInitiator']
RemoteBuildSpec = _reflection.GeneratedProtocolMessageType('RemoteBuildSpec', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEBUILDSPEC,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.RemoteBuildSpec)
  })
_sym_db.RegisterMessage(RemoteBuildSpec)

BuildPropertiesV1 = _reflection.GeneratedProtocolMessageType('BuildPropertiesV1', (_message.Message,), {
  'DESCRIPTOR' : _BUILDPROPERTIESV1,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildPropertiesV1)
  })
_sym_db.RegisterMessage(BuildPropertiesV1)

BuildProperties = _reflection.GeneratedProtocolMessageType('BuildProperties', (_message.Message,), {
  'DESCRIPTOR' : _BUILDPROPERTIES,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildProperties)
  })
_sym_db.RegisterMessage(BuildProperties)

ModelUriSpec = _reflection.GeneratedProtocolMessageType('ModelUriSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELURISPEC,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.ModelUriSpec)
  })
_sym_db.RegisterMessage(ModelUriSpec)

BuildEnv = _reflection.GeneratedProtocolMessageType('BuildEnv', (_message.Message,), {
  'DESCRIPTOR' : _BUILDENV,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildEnv)
  })
_sym_db.RegisterMessage(BuildEnv)

DockerEnv = _reflection.GeneratedProtocolMessageType('DockerEnv', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERENV,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.DockerEnv)
  })
_sym_db.RegisterMessage(DockerEnv)

PythonEnv = _reflection.GeneratedProtocolMessageType('PythonEnv', (_message.Message,), {
  'DESCRIPTOR' : _PYTHONENV,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.PythonEnv)
  })
_sym_db.RegisterMessage(PythonEnv)

CpuResources = _reflection.GeneratedProtocolMessageType('CpuResources', (_message.Message,), {
  'DESCRIPTOR' : _CPURESOURCES,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CpuResources)
  })
_sym_db.RegisterMessage(CpuResources)

GpuResources = _reflection.GeneratedProtocolMessageType('GpuResources', (_message.Message,), {
  'DESCRIPTOR' : _GPURESOURCES,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.GpuResources)
  })
_sym_db.RegisterMessage(GpuResources)

DataTableDefinition = _reflection.GeneratedProtocolMessageType('DataTableDefinition', (_message.Message,), {
  'DESCRIPTOR' : _DATATABLEDEFINITION,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.DataTableDefinition)
  })
_sym_db.RegisterMessage(DataTableDefinition)

DataColumnDefinition = _reflection.GeneratedProtocolMessageType('DataColumnDefinition', (_message.Message,), {
  'DESCRIPTOR' : _DATACOLUMNDEFINITION,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.DataColumnDefinition)
  })
_sym_db.RegisterMessage(DataColumnDefinition)

DataFormat = _reflection.GeneratedProtocolMessageType('DataFormat', (_message.Message,), {
  'DESCRIPTOR' : _DATAFORMAT,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.DataFormat)
  })
_sym_db.RegisterMessage(DataFormat)

CsvFormat = _reflection.GeneratedProtocolMessageType('CsvFormat', (_message.Message,), {
  'DESCRIPTOR' : _CSVFORMAT,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CsvFormat)
  })
_sym_db.RegisterMessage(CsvFormat)

BuildInitiator = _reflection.GeneratedProtocolMessageType('BuildInitiator', (_message.Message,), {
  'DESCRIPTOR' : _BUILDINITIATOR,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildInitiator)
  })
_sym_db.RegisterMessage(BuildInitiator)

UserBuildInitiator = _reflection.GeneratedProtocolMessageType('UserBuildInitiator', (_message.Message,), {
  'DESCRIPTOR' : _USERBUILDINITIATOR,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.UserBuildInitiator)
  })
_sym_db.RegisterMessage(UserBuildInitiator)

AutomationBuildInitiator = _reflection.GeneratedProtocolMessageType('AutomationBuildInitiator', (_message.Message,), {
  'DESCRIPTOR' : _AUTOMATIONBUILDINITIATOR,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.AutomationBuildInitiator)
  })
_sym_db.RegisterMessage(AutomationBuildInitiator)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.builds.orchestrator.apiP\001'
  _REMOTEBUILDSPEC.fields_by_name['cpu_resources']._options = None
  _REMOTEBUILDSPEC.fields_by_name['cpu_resources']._serialized_options = b'\030\001'
  _REMOTEBUILDSPEC.fields_by_name['gpu_resources']._options = None
  _REMOTEBUILDSPEC.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _MEMORYUNIT._serialized_start=2617
  _MEMORYUNIT._serialized_end=2672
  _GPUTYPE._serialized_start=2675
  _GPUTYPE._serialized_end=2943
  _DATACOLUMNTYPE._serialized_start=2945
  _DATACOLUMNTYPE._serialized_end=3045
  _BASEDOCKERIMAGETYPE._serialized_start=3047
  _BASEDOCKERIMAGETYPE._serialized_end=3122
  _REMOTEBUILDSPEC._serialized_start=139
  _REMOTEBUILDSPEC._serialized_end=887
  _BUILDPROPERTIESV1._serialized_start=889
  _BUILDPROPERTIESV1._serialized_end=992
  _BUILDPROPERTIES._serialized_start=995
  _BUILDPROPERTIES._serialized_end=1161
  _MODELURISPEC._serialized_start=1164
  _MODELURISPEC._serialized_end=1342
  _BUILDENV._serialized_start=1344
  _BUILDENV._serialized_end=1468
  _DOCKERENV._serialized_start=1471
  _DOCKERENV._serialized_end=1609
  _PYTHONENV._serialized_start=1611
  _PYTHONENV._serialized_end=1735
  _CPURESOURCES._serialized_start=1737
  _CPURESOURCES._serialized_end=1847
  _GPURESOURCES._serialized_start=1849
  _GPURESOURCES._serialized_end=1936
  _DATATABLEDEFINITION._serialized_start=1939
  _DATATABLEDEFINITION._serialized_end=2084
  _DATACOLUMNDEFINITION._serialized_start=2086
  _DATACOLUMNDEFINITION._serialized_end=2178
  _DATAFORMAT._serialized_start=2180
  _DATAFORMAT._serialized_end=2254
  _CSVFORMAT._serialized_start=2256
  _CSVFORMAT._serialized_end=2327
  _BUILDINITIATOR._serialized_start=2330
  _BUILDINITIATOR._serialized_end=2495
  _USERBUILDINITIATOR._serialized_start=2497
  _USERBUILDINITIATOR._serialized_end=2517
  _AUTOMATIONBUILDINITIATOR._serialized_start=2519
  _AUTOMATIONBUILDINITIATOR._serialized_end=2615
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.execution.v1.backfill_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _JobStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _JobStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_JobStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    JOB_STATUS_INVALID: _JobStatus.ValueType  # 0
    """reserved"""
    JOB_STATUS_SUCCESS: _JobStatus.ValueType  # 1
    """job successful"""
    JOB_STATUS_FAILURE: _JobStatus.ValueType  # 2
    """job failed"""
    JOB_STATUS_TOO_EARLY: _JobStatus.ValueType  # 3
    """job is too early"""

class JobStatus(_JobStatus, metaclass=_JobStatusEnumTypeWrapper): ...

JOB_STATUS_INVALID: JobStatus.ValueType  # 0
"""reserved"""
JOB_STATUS_SUCCESS: JobStatus.ValueType  # 1
"""job successful"""
JOB_STATUS_FAILURE: JobStatus.ValueType  # 2
"""job failed"""
JOB_STATUS_TOO_EARLY: JobStatus.ValueType  # 3
"""job is too early"""
global___JobStatus = JobStatus

class FailureInformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    error_message: builtins.str
    """holds the full stacktrace of the exception"""
    def __init__(
        self,
        *,
        error_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_message", b"error_message"]) -> None: ...

global___FailureInformation = FailureInformation

class BatchIngestionJobMetadata(google.protobuf.message.Message):
    """batchV1 job ingestion details"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_EXECUTION_DATE_FIELD_NUMBER: builtins.int
    INGESTION_WINDOW_START_TIME_FIELD_NUMBER: builtins.int
    INGESTION_WINDOW_END_TIME_FIELD_NUMBER: builtins.int
    @property
    def batch_execution_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """LOGICAL batch execution date (cron tick)"""
    @property
    def ingestion_window_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """LOGICAL ingestion window start time"""
    @property
    def ingestion_window_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """LOGICAL ingestion window end time"""
    def __init__(
        self,
        *,
        batch_execution_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ingestion_window_start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ingestion_window_end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_execution_date", b"batch_execution_date", "ingestion_window_end_time", b"ingestion_window_end_time", "ingestion_window_start_time", b"ingestion_window_start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_execution_date", b"batch_execution_date", "ingestion_window_end_time", b"ingestion_window_end_time", "ingestion_window_start_time", b"ingestion_window_start_time"]) -> None: ...

global___BatchIngestionJobMetadata = BatchIngestionJobMetadata

class BatchBackfillJobMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_INTERVAL_ROWS_FIELD_NUMBER: builtins.int
    BACKFILL_SPEC_FIELD_NUMBER: builtins.int
    OFFLINE_PROCESSING_START_TIME_FIELD_NUMBER: builtins.int
    OFFLINE_PROCESSING_END_TIME_FIELD_NUMBER: builtins.int
    ONLINE_PROCESSING_START_TIME_FIELD_NUMBER: builtins.int
    ONLINE_PROCESSING_END_TIME_FIELD_NUMBER: builtins.int
    LAST_BATCH_LOGICAL_DATE_FIELD_NUMBER: builtins.int
    num_interval_rows: builtins.int
    """number of incoming rows in the interval"""
    @property
    def backfill_spec(self) -> qwak.execution.v1.backfill_pb2.BackfillSpec:
        """number of rows affected by the backfill"""
    @property
    def offline_processing_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """SYSTEM time where offline processing started"""
    @property
    def offline_processing_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """SYSTEM time where offline processing ended"""
    @property
    def online_processing_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """SYSTEM time when online processing started"""
    @property
    def online_processing_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """SYSTEM time when online processing ended"""
    @property
    def last_batch_logical_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Cron tick of last ingestion (window end time)"""
    def __init__(
        self,
        *,
        num_interval_rows: builtins.int = ...,
        backfill_spec: qwak.execution.v1.backfill_pb2.BackfillSpec | None = ...,
        offline_processing_start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        offline_processing_end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        online_processing_start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        online_processing_end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_batch_logical_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec", "last_batch_logical_date", b"last_batch_logical_date", "offline_processing_end_time", b"offline_processing_end_time", "offline_processing_start_time", b"offline_processing_start_time", "online_processing_end_time", b"online_processing_end_time", "online_processing_start_time", b"online_processing_start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec", "last_batch_logical_date", b"last_batch_logical_date", "num_interval_rows", b"num_interval_rows", "offline_processing_end_time", b"offline_processing_end_time", "offline_processing_start_time", b"offline_processing_start_time", "online_processing_end_time", b"online_processing_end_time", "online_processing_start_time", b"online_processing_start_time"]) -> None: ...

global___BatchBackfillJobMetadata = BatchBackfillJobMetadata

class StreamingJobMetadata(google.protobuf.message.Message):
    """row-level streaming"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StreamingJobMetadata = StreamingJobMetadata

class StreamingAggregationJobMetadata(google.protobuf.message.Message):
    """streaming aggregation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StreamingAggregationJobMetadata = StreamingAggregationJobMetadata

class JobReport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class JobLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BATCH_INGESTION_METADATA_FIELD_NUMBER: builtins.int
    STREAMING_JOB_METADATA_FIELD_NUMBER: builtins.int
    STREAMING_AGGR_JOB_METADATA_FIELD_NUMBER: builtins.int
    BATCH_BACKFILL_JOB_METADATA_FIELD_NUMBER: builtins.int
    NUM_AFFECTED_RECORDS_FIELD_NUMBER: builtins.int
    RUN_START_TIME_FIELD_NUMBER: builtins.int
    RUN_END_TIME_FIELD_NUMBER: builtins.int
    LEGACY_RUN_ID_FIELD_NUMBER: builtins.int
    EXECUTION_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    FEATURESET_ID_FIELD_NUMBER: builtins.int
    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    JOB_LABELS_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    @property
    def batch_ingestion_metadata(self) -> global___BatchIngestionJobMetadata: ...
    @property
    def streaming_job_metadata(self) -> global___StreamingJobMetadata: ...
    @property
    def streaming_aggr_job_metadata(self) -> global___StreamingAggregationJobMetadata: ...
    @property
    def batch_backfill_job_metadata(self) -> global___BatchBackfillJobMetadata: ...
    num_affected_records: builtins.int
    """number of affected records"""
    @property
    def run_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """SYSTEM start time of the job"""
    @property
    def run_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """SYSTEM end time of the job"""
    legacy_run_id: builtins.int
    """legacy run id (what used to be called execution_id in the old report"""
    execution_id: builtins.str
    """Execution Manager Execution ID"""
    environment_id: builtins.str
    """environment_id"""
    featureset_id: builtins.str
    """featureset id"""
    featureset_name: builtins.str
    """featureset name"""
    status: global___JobStatus.ValueType
    """job status"""
    @property
    def job_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """general tags/labels"""
    job_id: builtins.str
    """Job ID"""
    @property
    def info(self) -> global___FailureInformation: ...
    def __init__(
        self,
        *,
        batch_ingestion_metadata: global___BatchIngestionJobMetadata | None = ...,
        streaming_job_metadata: global___StreamingJobMetadata | None = ...,
        streaming_aggr_job_metadata: global___StreamingAggregationJobMetadata | None = ...,
        batch_backfill_job_metadata: global___BatchBackfillJobMetadata | None = ...,
        num_affected_records: builtins.int = ...,
        run_start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        run_end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        legacy_run_id: builtins.int = ...,
        execution_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        featureset_id: builtins.str = ...,
        featureset_name: builtins.str = ...,
        status: global___JobStatus.ValueType = ...,
        job_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        job_id: builtins.str = ...,
        info: global___FailureInformation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_backfill_job_metadata", b"batch_backfill_job_metadata", "batch_ingestion_metadata", b"batch_ingestion_metadata", "execution_id", b"execution_id", "execution_identifier", b"execution_identifier", "failure_info", b"failure_info", "info", b"info", "job_metadata_type", b"job_metadata_type", "legacy_run_id", b"legacy_run_id", "run_end_time", b"run_end_time", "run_start_time", b"run_start_time", "streaming_aggr_job_metadata", b"streaming_aggr_job_metadata", "streaming_job_metadata", b"streaming_job_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_backfill_job_metadata", b"batch_backfill_job_metadata", "batch_ingestion_metadata", b"batch_ingestion_metadata", "environment_id", b"environment_id", "execution_id", b"execution_id", "execution_identifier", b"execution_identifier", "failure_info", b"failure_info", "featureset_id", b"featureset_id", "featureset_name", b"featureset_name", "info", b"info", "job_id", b"job_id", "job_labels", b"job_labels", "job_metadata_type", b"job_metadata_type", "legacy_run_id", b"legacy_run_id", "num_affected_records", b"num_affected_records", "run_end_time", b"run_end_time", "run_start_time", b"run_start_time", "status", b"status", "streaming_aggr_job_metadata", b"streaming_aggr_job_metadata", "streaming_job_metadata", b"streaming_job_metadata"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["execution_identifier", b"execution_identifier"]) -> typing_extensions.Literal["legacy_run_id", "execution_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["failure_info", b"failure_info"]) -> typing_extensions.Literal["info"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["job_metadata_type", b"job_metadata_type"]) -> typing_extensions.Literal["batch_ingestion_metadata", "streaming_job_metadata", "streaming_aggr_job_metadata", "batch_backfill_job_metadata"] | None: ...

global___JobReport = JobReport



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/account_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.account.v1 import account_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_account__pb2
from _qwak_proto.qwak.administration.account.v1 import preferences_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_preferences__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4qwak/administration/account/v1/account_service.proto\x12\x1eqwak.administration.account.v1\x1a,qwak/administration/account/v1/account.proto\x1a\x30qwak/administration/account/v1/preferences.proto\"\xe8\x01\n\x14\x43reateAccountRequest\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x44\n\x0bpreferences\x18\x02 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\x04 \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\"Q\n\x15\x43reateAccountResponse\x12\x38\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\'.qwak.administration.account.v1.Account\"\'\n\x11GetAccountRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\"N\n\x12GetAccountResponse\x12\x38\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\'.qwak.administration.account.v1.Account\"X\n\x13ListAccountsRequest\x12\x41\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x31.qwak.administration.account.v1.ListAccountFilter\"Q\n\x14ListAccountsResponse\x12\x39\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\'.qwak.administration.account.v1.Account\"\xe6\x01\n\x14UpdateAccountRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x44\n\x0bpreferences\x18\x02 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\x04 \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\"\x17\n\x15UpdateAccountResponse\"{\n\x1fUpdateAccountPreferencesRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x44\n\x0bpreferences\x18\x02 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\"\"\n UpdateAccountPreferencesResponse\"z\n\x15\x41\x64\x64\x41utoBindingRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12M\n\x14\x61uto_binding_account\x18\x02 \x03(\x0b\x32/.qwak.administration.account.v1.AutoBindingRule\"j\n\x16\x41\x64\x64\x41utoBindingResponse\x12P\n\x14\x61uto_binding_account\x18\x01 \x03(\x0b\x32\x32.qwak.administration.account.v1.AutoBindingAccount\"Q\n\x18RemoveAutoBindingRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12!\n\x19\x61uto_binding_id_to_remove\x18\x02 \x03(\t\"\x1b\n\x19RemoveAutoBindingResponse2\xa8\x07\n\x0e\x41\x63\x63ountService\x12|\n\rCreateAccount\x12\x34.qwak.administration.account.v1.CreateAccountRequest\x1a\x35.qwak.administration.account.v1.CreateAccountResponse\x12s\n\nGetAccount\x12\x31.qwak.administration.account.v1.GetAccountRequest\x1a\x32.qwak.administration.account.v1.GetAccountResponse\x12y\n\x0cListAccounts\x12\x33.qwak.administration.account.v1.ListAccountsRequest\x1a\x34.qwak.administration.account.v1.ListAccountsResponse\x12|\n\rUpdateAccount\x12\x34.qwak.administration.account.v1.UpdateAccountRequest\x1a\x35.qwak.administration.account.v1.UpdateAccountResponse\x12\x9d\x01\n\x18UpdateAccountPreferences\x12?.qwak.administration.account.v1.UpdateAccountPreferencesRequest\x1a@.qwak.administration.account.v1.UpdateAccountPreferencesResponse\x12\x7f\n\x0e\x41\x64\x64\x41utoBinding\x12\x35.qwak.administration.account.v1.AddAutoBindingRequest\x1a\x36.qwak.administration.account.v1.AddAutoBindingResponse\x12\x88\x01\n\x11RemoveAutoBinding\x12\x38.qwak.administration.account.v1.RemoveAutoBindingRequest\x1a\x39.qwak.administration.account.v1.RemoveAutoBindingResponseB\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')



_CREATEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['CreateAccountRequest']
_CREATEACCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['CreateAccountResponse']
_GETACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['GetAccountRequest']
_GETACCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['GetAccountResponse']
_LISTACCOUNTSREQUEST = DESCRIPTOR.message_types_by_name['ListAccountsRequest']
_LISTACCOUNTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAccountsResponse']
_UPDATEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAccountRequest']
_UPDATEACCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateAccountResponse']
_UPDATEACCOUNTPREFERENCESREQUEST = DESCRIPTOR.message_types_by_name['UpdateAccountPreferencesRequest']
_UPDATEACCOUNTPREFERENCESRESPONSE = DESCRIPTOR.message_types_by_name['UpdateAccountPreferencesResponse']
_ADDAUTOBINDINGREQUEST = DESCRIPTOR.message_types_by_name['AddAutoBindingRequest']
_ADDAUTOBINDINGRESPONSE = DESCRIPTOR.message_types_by_name['AddAutoBindingResponse']
_REMOVEAUTOBINDINGREQUEST = DESCRIPTOR.message_types_by_name['RemoveAutoBindingRequest']
_REMOVEAUTOBINDINGRESPONSE = DESCRIPTOR.message_types_by_name['RemoveAutoBindingResponse']
CreateAccountRequest = _reflection.GeneratedProtocolMessageType('CreateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.CreateAccountRequest)
  })
_sym_db.RegisterMessage(CreateAccountRequest)

CreateAccountResponse = _reflection.GeneratedProtocolMessageType('CreateAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.CreateAccountResponse)
  })
_sym_db.RegisterMessage(CreateAccountResponse)

GetAccountRequest = _reflection.GeneratedProtocolMessageType('GetAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.GetAccountRequest)
  })
_sym_db.RegisterMessage(GetAccountRequest)

GetAccountResponse = _reflection.GeneratedProtocolMessageType('GetAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.GetAccountResponse)
  })
_sym_db.RegisterMessage(GetAccountResponse)

ListAccountsRequest = _reflection.GeneratedProtocolMessageType('ListAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.ListAccountsRequest)
  })
_sym_db.RegisterMessage(ListAccountsRequest)

ListAccountsResponse = _reflection.GeneratedProtocolMessageType('ListAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.ListAccountsResponse)
  })
_sym_db.RegisterMessage(ListAccountsResponse)

UpdateAccountRequest = _reflection.GeneratedProtocolMessageType('UpdateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.UpdateAccountRequest)
  })
_sym_db.RegisterMessage(UpdateAccountRequest)

UpdateAccountResponse = _reflection.GeneratedProtocolMessageType('UpdateAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.UpdateAccountResponse)
  })
_sym_db.RegisterMessage(UpdateAccountResponse)

UpdateAccountPreferencesRequest = _reflection.GeneratedProtocolMessageType('UpdateAccountPreferencesRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTPREFERENCESREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.UpdateAccountPreferencesRequest)
  })
_sym_db.RegisterMessage(UpdateAccountPreferencesRequest)

UpdateAccountPreferencesResponse = _reflection.GeneratedProtocolMessageType('UpdateAccountPreferencesResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTPREFERENCESRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.UpdateAccountPreferencesResponse)
  })
_sym_db.RegisterMessage(UpdateAccountPreferencesResponse)

AddAutoBindingRequest = _reflection.GeneratedProtocolMessageType('AddAutoBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDAUTOBINDINGREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.AddAutoBindingRequest)
  })
_sym_db.RegisterMessage(AddAutoBindingRequest)

AddAutoBindingResponse = _reflection.GeneratedProtocolMessageType('AddAutoBindingResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDAUTOBINDINGRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.AddAutoBindingResponse)
  })
_sym_db.RegisterMessage(AddAutoBindingResponse)

RemoveAutoBindingRequest = _reflection.GeneratedProtocolMessageType('RemoveAutoBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEAUTOBINDINGREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.RemoveAutoBindingRequest)
  })
_sym_db.RegisterMessage(RemoveAutoBindingRequest)

RemoveAutoBindingResponse = _reflection.GeneratedProtocolMessageType('RemoveAutoBindingResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEAUTOBINDINGRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.RemoveAutoBindingResponse)
  })
_sym_db.RegisterMessage(RemoveAutoBindingResponse)

_ACCOUNTSERVICE = DESCRIPTOR.services_by_name['AccountService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _CREATEACCOUNTREQUEST._serialized_start=185
  _CREATEACCOUNTREQUEST._serialized_end=417
  _CREATEACCOUNTRESPONSE._serialized_start=419
  _CREATEACCOUNTRESPONSE._serialized_end=500
  _GETACCOUNTREQUEST._serialized_start=502
  _GETACCOUNTREQUEST._serialized_end=541
  _GETACCOUNTRESPONSE._serialized_start=543
  _GETACCOUNTRESPONSE._serialized_end=621
  _LISTACCOUNTSREQUEST._serialized_start=623
  _LISTACCOUNTSREQUEST._serialized_end=711
  _LISTACCOUNTSRESPONSE._serialized_start=713
  _LISTACCOUNTSRESPONSE._serialized_end=794
  _UPDATEACCOUNTREQUEST._serialized_start=797
  _UPDATEACCOUNTREQUEST._serialized_end=1027
  _UPDATEACCOUNTRESPONSE._serialized_start=1029
  _UPDATEACCOUNTRESPONSE._serialized_end=1052
  _UPDATEACCOUNTPREFERENCESREQUEST._serialized_start=1054
  _UPDATEACCOUNTPREFERENCESREQUEST._serialized_end=1177
  _UPDATEACCOUNTPREFERENCESRESPONSE._serialized_start=1179
  _UPDATEACCOUNTPREFERENCESRESPONSE._serialized_end=1213
  _ADDAUTOBINDINGREQUEST._serialized_start=1215
  _ADDAUTOBINDINGREQUEST._serialized_end=1337
  _ADDAUTOBINDINGRESPONSE._serialized_start=1339
  _ADDAUTOBINDINGRESPONSE._serialized_end=1445
  _REMOVEAUTOBINDINGREQUEST._serialized_start=1447
  _REMOVEAUTOBINDINGREQUEST._serialized_end=1528
  _REMOVEAUTOBINDINGRESPONSE._serialized_start=1530
  _REMOVEAUTOBINDINGRESPONSE._serialized_end=1557
  _ACCOUNTSERVICE._serialized_start=1560
  _ACCOUNTSERVICE._serialized_end=2496
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.feature_store.features import feature_set_service_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2


class FeatureSetServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterFeatureSet = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/RegisterFeatureSet',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RegisterFeatureSetRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RegisterFeatureSetResponse.FromString,
                )
        self.UpdateFeatureSet = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/UpdateFeatureSet',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetResponse.FromString,
                )
        self.GetFeatureSetById = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/GetFeatureSetById',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByIdResponse.FromString,
                )
        self.GetFeatureSetByName = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/GetFeatureSetByName',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByNameResponse.FromString,
                )
        self.DeleteFeatureSet = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/DeleteFeatureSet',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.DeleteFeatureSetRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.DeleteFeatureSetResponse.FromString,
                )
        self.ListFeatureSets = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/ListFeatureSets',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ListFeatureSetsRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ListFeatureSetsResponse.FromString,
                )
        self.RunBatchFeatureSet = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/RunBatchFeatureSet',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunBatchFeatureSetRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunBatchFeatureSetResponse.FromString,
                )
        self.RunParquetBatchFeatureSet = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/RunParquetBatchFeatureSet',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunParquetBatchFeatureSetRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunParquetBatchFeatureSetResponse.FromString,
                )
        self.CreateUploadURL = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/CreateUploadURL',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLResponse.FromString,
                )
        self.CreateUploadURLV1 = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/CreateUploadURLV1',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLRequestV1.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLResponse.FromString,
                )
        self.CreateRealTimeFeatureExtractorUploadURL = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/CreateRealTimeFeatureExtractorUploadURL',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateRealTimeFeatureExtractorUploadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLResponse.FromString,
                )
        self.UpdateFeatureSetState = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/UpdateFeatureSetState',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetStateRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetStateResponse.FromString,
                )
        self.GetFeatureSetStateByName = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/GetFeatureSetStateByName',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByNameResponse.FromString,
                )
        self.GetFeatureSetStateById = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/GetFeatureSetStateById',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByIdResponse.FromString,
                )
        self.PauseFeatureset = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/PauseFeatureset',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.PauseFeaturesetRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.PauseFeaturesetResponse.FromString,
                )
        self.ResumeFeatureset = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/ResumeFeatureset',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ResumeFeaturesetRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ResumeFeaturesetResponse.FromString,
                )
        self.GetFeaturesetSchedulingState = channel.unary_unary(
                '/qwak.feature.store.features.FeatureSetService/GetFeaturesetSchedulingState',
                request_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeaturesetSchedulingStateRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeaturesetSchedulingStateResponse.FromString,
                )


class FeatureSetServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RegisterFeatureSet(self, request, context):
        """Register a feature set to the registry
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSet(self, request, context):
        """Update an existing feature set's state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetById(self, request, context):
        """Get a feature set by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetByName(self, request, context):
        """Get a feature set by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureSet(self, request, context):
        """Delete a feature from the registry
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSets(self, request, context):
        """List all registered features
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunBatchFeatureSet(self, request, context):
        """Run now feature set
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunParquetBatchFeatureSet(self, request, context):
        """Run now feature set parquet dataframe ingestion
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUploadURL(self, request, context):
        """Create a url for uploading
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUploadURLV1(self, request, context):
        """Create a url for uploading artifacts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRealTimeFeatureExtractorUploadURL(self, request, context):
        """Create a url for uploading real time feature extractor code artifact
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetState(self, request, context):
        """Update an existing feature set
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetStateByName(self, request, context):
        """Get Feature Set State by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetStateById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseFeatureset(self, request, context):
        """Pause a Featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeFeatureset(self, request, context):
        """Resume a Featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeaturesetSchedulingState(self, request, context):
        """Get Feature Set scheduling state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureSetServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterFeatureSet,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RegisterFeatureSetRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RegisterFeatureSetResponse.SerializeToString,
            ),
            'UpdateFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSet,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetResponse.SerializeToString,
            ),
            'GetFeatureSetById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetById,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByIdRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByIdResponse.SerializeToString,
            ),
            'GetFeatureSetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetByName,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByNameRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByNameResponse.SerializeToString,
            ),
            'DeleteFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureSet,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.DeleteFeatureSetRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.DeleteFeatureSetResponse.SerializeToString,
            ),
            'ListFeatureSets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSets,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ListFeatureSetsRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ListFeatureSetsResponse.SerializeToString,
            ),
            'RunBatchFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.RunBatchFeatureSet,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunBatchFeatureSetRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunBatchFeatureSetResponse.SerializeToString,
            ),
            'RunParquetBatchFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.RunParquetBatchFeatureSet,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunParquetBatchFeatureSetRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunParquetBatchFeatureSetResponse.SerializeToString,
            ),
            'CreateUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUploadURL,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLResponse.SerializeToString,
            ),
            'CreateUploadURLV1': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUploadURLV1,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLRequestV1.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLResponse.SerializeToString,
            ),
            'CreateRealTimeFeatureExtractorUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRealTimeFeatureExtractorUploadURL,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateRealTimeFeatureExtractorUploadURLRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLResponse.SerializeToString,
            ),
            'UpdateFeatureSetState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetState,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetStateRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetStateResponse.SerializeToString,
            ),
            'GetFeatureSetStateByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetStateByName,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByNameRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByNameResponse.SerializeToString,
            ),
            'GetFeatureSetStateById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetStateById,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByIdRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByIdResponse.SerializeToString,
            ),
            'PauseFeatureset': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseFeatureset,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.PauseFeaturesetRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.PauseFeaturesetResponse.SerializeToString,
            ),
            'ResumeFeatureset': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeFeatureset,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ResumeFeaturesetRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ResumeFeaturesetResponse.SerializeToString,
            ),
            'GetFeaturesetSchedulingState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturesetSchedulingState,
                    request_deserializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeaturesetSchedulingStateRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeaturesetSchedulingStateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.features.FeatureSetService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureSetService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RegisterFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/RegisterFeatureSet',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RegisterFeatureSetRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RegisterFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/UpdateFeatureSet',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/GetFeatureSetById',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByIdRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/GetFeatureSetByName',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByNameRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/DeleteFeatureSet',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.DeleteFeatureSetRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.DeleteFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/ListFeatureSets',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ListFeatureSetsRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ListFeatureSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunBatchFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/RunBatchFeatureSet',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunBatchFeatureSetRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunBatchFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunParquetBatchFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/RunParquetBatchFeatureSet',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunParquetBatchFeatureSetRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.RunParquetBatchFeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/CreateUploadURL',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUploadURLV1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/CreateUploadURLV1',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLRequestV1.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRealTimeFeatureExtractorUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/CreateRealTimeFeatureExtractorUploadURL',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateRealTimeFeatureExtractorUploadURLRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.CreateUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/UpdateFeatureSetState',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetStateRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.UpdateFeatureSetStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetStateByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/GetFeatureSetStateByName',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByNameRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetStateById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/GetFeatureSetStateById',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByIdRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeatureSetStateByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseFeatureset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/PauseFeatureset',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.PauseFeaturesetRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.PauseFeaturesetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeFeatureset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/ResumeFeatureset',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ResumeFeaturesetRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.ResumeFeaturesetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeaturesetSchedulingState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.features.FeatureSetService/GetFeaturesetSchedulingState',
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeaturesetSchedulingStateRequest.SerializeToString,
            qwak_dot_feature__store_dot_features_dot_feature__set__service__pb2.GetFeaturesetSchedulingStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import uuid
from typing import Optional

from _qwak_proto.qwak.offline.serving.v1.offline_serving_async_service_pb2 import (
    GetFeatureValuesInRangeResponse,
    GetFeatureValuesResponse,
    GetFeatureValuesResultResponse,
    GetFileUploadUrlResponse,
)
from _qwak_proto.qwak.offline.serving.v1.offline_serving_async_service_pb2_grpc import (
    FeatureStoreOfflineServingAsyncServiceServicer,
)


class FsOfflineServingServiceMock(FeatureStoreOfflineServingAsyncServiceServicer):
    def __init__(self):
        self.file_upload_url_response: Optional[GetFileUploadUrlResponse] = None
        self.response: Optional[GetFeatureValuesResultResponse] = None
        super(FsOfflineServingServiceMock, self).__init__()

    def given_next_file_upload_url(
        self, file_upload_url_response: GetFileUploadUrlResponse
    ):
        self.file_upload_url_response = file_upload_url_response

    def given_next_response(self, response: GetFeatureValuesResultResponse):
        self.response = response

    def GetFileUploadUrl(self, request, context) -> Optional[GetFileUploadUrlResponse]:
        return self.file_upload_url_response

    def GetFeatureValues(self, request, context) -> GetFeatureValuesResponse:
        request_id = str(uuid.uuid4())
        return GetFeatureValuesResponse(request_id=request_id)

    def GetFeatureValuesInRange(self, request, context):
        request_id = str(uuid.uuid4())
        return GetFeatureValuesInRangeResponse(request_id=request_id)

    def GetFeatureValuesResult(
        self, request, context
    ) -> Optional[GetFeatureValuesResultResponse]:
        return self.response



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/pagerduty_integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/integration/pagerduty_integration.proto\x12\x1bqwak.integration.management\"\xf4\x01\n\x14PagerdutyIntegration\x12]\n\x1f\x65ncrypted_pagerduty_auth_config\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.PagerdutyAuthConfigB\x02\x18\x01\x12\x14\n\x0c\x65ndpoint_url\x18\x02 \x01(\t\x12_\n\x17pagerduty_system_secret\x18\x03 \x01(\x0b\x32<.qwak.integration.management.PagerdutySystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"|\n\x18PagerdutyIntegrationSpec\x12X\n\x1cpagerduty_auth_configuration\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.PagerdutyAuthConfigH\x00\x42\x06\n\x04\x61uth\"\xd3\x01\n\x13PagerdutyAuthConfig\x12Y\n\x15\x65vents_v1_auth_config\x18\x01 \x01(\x0b\x32\x38.qwak.integration.management.PagerdutyEventsV1AuthConfigH\x00\x12Y\n\x15\x65vents_v2_auth_config\x18\x02 \x01(\x0b\x32\x38.qwak.integration.management.PagerdutyEventsV2AuthConfigH\x00\x42\x06\n\x04\x61uth\"2\n\x1bPagerdutyEventsV1AuthConfig\x12\x13\n\x0bservice_key\x18\x01 \x01(\t\"2\n\x1bPagerdutyEventsV2AuthConfig\x12\x13\n\x0brouting_key\x18\x01 \x01(\t\"\xb0\x02\n\x1fPagerdutySystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12q\n!pagerduty_events_v1_system_secret\x18\x02 \x01(\x0b\x32\x44.qwak.integration.management.PagerdutyEventsV1SystemSecretDescriptorH\x00\x12q\n!pagerduty_events_v2_system_secret\x18\x03 \x01(\x0b\x32\x44.qwak.integration.management.PagerdutyEventsV2SystemSecretDescriptorH\x00\x42\x12\n\x10pagerduty_secret\"I\n\'PagerdutyEventsV1SystemSecretDescriptor\x12\x1e\n\x16service_key_secret_key\x18\x01 \x01(\t\"I\n\'PagerdutyEventsV2SystemSecretDescriptor\x12\x1e\n\x16routing_key_secret_key\x18\x01 \x01(\t\"j\n\x17PagerdutyValidationSpec\x12O\n\x15pagerduty_auth_config\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.PagerdutyAuthConfig\"\x1d\n\x1bPagerdutyIntegrationOptionsBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')



_PAGERDUTYINTEGRATION = DESCRIPTOR.message_types_by_name['PagerdutyIntegration']
_PAGERDUTYINTEGRATIONSPEC = DESCRIPTOR.message_types_by_name['PagerdutyIntegrationSpec']
_PAGERDUTYAUTHCONFIG = DESCRIPTOR.message_types_by_name['PagerdutyAuthConfig']
_PAGERDUTYEVENTSV1AUTHCONFIG = DESCRIPTOR.message_types_by_name['PagerdutyEventsV1AuthConfig']
_PAGERDUTYEVENTSV2AUTHCONFIG = DESCRIPTOR.message_types_by_name['PagerdutyEventsV2AuthConfig']
_PAGERDUTYSYSTEMSECRETDESCRIPTOR = DESCRIPTOR.message_types_by_name['PagerdutySystemSecretDescriptor']
_PAGERDUTYEVENTSV1SYSTEMSECRETDESCRIPTOR = DESCRIPTOR.message_types_by_name['PagerdutyEventsV1SystemSecretDescriptor']
_PAGERDUTYEVENTSV2SYSTEMSECRETDESCRIPTOR = DESCRIPTOR.message_types_by_name['PagerdutyEventsV2SystemSecretDescriptor']
_PAGERDUTYVALIDATIONSPEC = DESCRIPTOR.message_types_by_name['PagerdutyValidationSpec']
_PAGERDUTYINTEGRATIONOPTIONS = DESCRIPTOR.message_types_by_name['PagerdutyIntegrationOptions']
PagerdutyIntegration = _reflection.GeneratedProtocolMessageType('PagerdutyIntegration', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYINTEGRATION,
  '__module__' : 'qwak.integration.pagerduty_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.PagerdutyIntegration)
  })
_sym_db.RegisterMessage(PagerdutyIntegration)

PagerdutyIntegrationSpec = _reflection.GeneratedProtocolMessageType('PagerdutyIntegrationSpec', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYINTEGRATIONSPEC,
  '__module__' : 'qwak.integration.pagerduty_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.PagerdutyIntegrationSpec)
  })
_sym_db.RegisterMessage(PagerdutyIntegrationSpec)

PagerdutyAuthConfig = _reflection.GeneratedProtocolMessageType('PagerdutyAuthConfig', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYAUTHCONFIG,
  '__module__' : 'qwak.integration.pagerduty_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.PagerdutyAuthConfig)
  })
_sym_db.RegisterMessage(PagerdutyAuthConfig)

PagerdutyEventsV1AuthConfig = _reflection.GeneratedProtocolMessageType('PagerdutyEventsV1AuthConfig', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYEVENTSV1AUTHCONFIG,
  '__module__' : 'qwak.integration.pagerduty_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.PagerdutyEventsV1AuthConfig)
  })
_sym_db.RegisterMessage(PagerdutyEventsV1AuthConfig)

PagerdutyEventsV2AuthConfig = _reflection.GeneratedProtocolMessageType('PagerdutyEventsV2AuthConfig', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYEVENTSV2AUTHCONFIG,
  '__module__' : 'qwak.integration.pagerduty_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.PagerdutyEventsV2AuthConfig)
  })
_sym_db.RegisterMessage(PagerdutyEventsV2AuthConfig)

PagerdutySystemSecretDescriptor = _reflection.GeneratedProtocolMessageType('PagerdutySystemSecretDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYSYSTEMSECRETDESCRIPTOR,
  '__module__' : 'qwak.integration.pagerduty_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.PagerdutySystemSecretDescriptor)
  })
_sym_db.RegisterMessage(PagerdutySystemSecretDescriptor)

PagerdutyEventsV1SystemSecretDescriptor = _reflection.GeneratedProtocolMessageType('PagerdutyEventsV1SystemSecretDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYEVENTSV1SYSTEMSECRETDESCRIPTOR,
  '__module__' : 'qwak.integration.pagerduty_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.PagerdutyEventsV1SystemSecretDescriptor)
  })
_sym_db.RegisterMessage(PagerdutyEventsV1SystemSecretDescriptor)

PagerdutyEventsV2SystemSecretDescriptor = _reflection.GeneratedProtocolMessageType('PagerdutyEventsV2SystemSecretDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYEVENTSV2SYSTEMSECRETDESCRIPTOR,
  '__module__' : 'qwak.integration.pagerduty_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.PagerdutyEventsV2SystemSecretDescriptor)
  })
_sym_db.RegisterMessage(PagerdutyEventsV2SystemSecretDescriptor)

PagerdutyValidationSpec = _reflection.GeneratedProtocolMessageType('PagerdutyValidationSpec', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYVALIDATIONSPEC,
  '__module__' : 'qwak.integration.pagerduty_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.PagerdutyValidationSpec)
  })
_sym_db.RegisterMessage(PagerdutyValidationSpec)

PagerdutyIntegrationOptions = _reflection.GeneratedProtocolMessageType('PagerdutyIntegrationOptions', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYINTEGRATIONOPTIONS,
  '__module__' : 'qwak.integration.pagerduty_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.PagerdutyIntegrationOptions)
  })
_sym_db.RegisterMessage(PagerdutyIntegrationOptions)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _PAGERDUTYINTEGRATION.fields_by_name['encrypted_pagerduty_auth_config']._options = None
  _PAGERDUTYINTEGRATION.fields_by_name['encrypted_pagerduty_auth_config']._serialized_options = b'\030\001'
  _PAGERDUTYINTEGRATION._serialized_start=78
  _PAGERDUTYINTEGRATION._serialized_end=322
  _PAGERDUTYINTEGRATIONSPEC._serialized_start=324
  _PAGERDUTYINTEGRATIONSPEC._serialized_end=448
  _PAGERDUTYAUTHCONFIG._serialized_start=451
  _PAGERDUTYAUTHCONFIG._serialized_end=662
  _PAGERDUTYEVENTSV1AUTHCONFIG._serialized_start=664
  _PAGERDUTYEVENTSV1AUTHCONFIG._serialized_end=714
  _PAGERDUTYEVENTSV2AUTHCONFIG._serialized_start=716
  _PAGERDUTYEVENTSV2AUTHCONFIG._serialized_end=766
  _PAGERDUTYSYSTEMSECRETDESCRIPTOR._serialized_start=769
  _PAGERDUTYSYSTEMSECRETDESCRIPTOR._serialized_end=1073
  _PAGERDUTYEVENTSV1SYSTEMSECRETDESCRIPTOR._serialized_start=1075
  _PAGERDUTYEVENTSV1SYSTEMSECRETDESCRIPTOR._serialized_end=1148
  _PAGERDUTYEVENTSV2SYSTEMSECRETDESCRIPTOR._serialized_start=1150
  _PAGERDUTYEVENTSV2SYSTEMSECRETDESCRIPTOR._serialized_end=1223
  _PAGERDUTYVALIDATIONSPEC._serialized_start=1225
  _PAGERDUTYVALIDATIONSPEC._serialized_end=1331
  _PAGERDUTYINTEGRATIONOPTIONS._serialized_start=1333
  _PAGERDUTYINTEGRATIONOPTIONS._serialized_end=1362
# @@protoc_insertion_point(module_scope)



import contextlib
import os
import zipfile
from io import BytesIO
from pathlib import Path
from typing import TYPE_CHECKING, Callable, List, Union

import requests
from qwak.clients.feature_store.management_client import FeatureRegistryClient
from qwak.exceptions import QwakException

ZIP_FUNCTION_CONTENT_TYPE = "text/plain"

if TYPE_CHECKING:
    from qwak.feature_store.data_sources.streaming.kafka.deserialization import (
        Deserializer,
    )
    from qwak.feature_store.feature_sets.transformations.transformations import (
        BaseTransformation,
    )


def zip_function_with_base_folder(
    functions: List[Callable], fs_object_module_dir: Path = None
) -> bytes:
    """
    Prepare zip bytes of the UDF functions and it's parent folder
    In case the functions param is a Callable it will write the pkled code to "function.pkl" (original flow)
    If a list of functions it will write each function to {function_name}.pkl
    Args:
        functions: udf functions
        fs_object_module_dir: parent directory path of the registered feature store object
    Returns:
        bytes representing the zip bytes of the udf functions pkl and module
    """
    try:
        import cloudpickle
    except ImportError:
        raise QwakException(
            "Please install the cloudpickle package in your environment"
        )

    in_memory = BytesIO()
    with chdir(fs_object_module_dir):
        zf = zipfile.ZipFile(in_memory, mode="w")
        with zf:
            if fs_object_module_dir:
                for path in Path.cwd().glob("**/*"):
                    str_path = (
                        f"./{path.relative_to(Path.cwd())}"
                        if path.is_file()
                        else str(path.resolve())
                    )
                    zf.write(str_path, "code" + "/" + str_path)
            for function in functions:
                zf.writestr(f"{function.__name__}.pkl", cloudpickle.dumps(function))
        in_memory.seek(0)
    return in_memory.read()


@contextlib.contextmanager
def chdir(dirname: Path = None):
    """
    chdir to given path and return to previous cwd when done
    Args:
        dirname: dir to chdir into
    """
    current_dir = Path.cwd()
    try:
        if dirname is not None:
            os.chdir(dirname)
        yield
    finally:
        os.chdir(current_dir)


def get_featureset_presign_url(
    features_manager_client: FeatureRegistryClient,
    feature_store_object_name: str,
    feature_store_object_name_suffix: str,
    transformation,
) -> str:
    return features_manager_client.get_presigned_url_v1(
        feature_set_name=feature_store_object_name + feature_store_object_name_suffix,
        transformation=transformation._to_proto(),
    )


def get_data_source_presign_url_v1(
    features_manager_client: FeatureRegistryClient,
    data_source_object_name: str,
    data_source_name_suffix: str,
) -> str:
    return features_manager_client.get_data_source_presigned_url_v1(
        data_source_name=data_source_object_name, object_name=data_source_name_suffix
    )


def upload_artifact(
    feature_store_object_name: str,
    feature_store_object_name_suffix: str,
    functions: List[Callable],
    feature_module_dir: Path,
    features_manager_client: FeatureRegistryClient,
    artifact_object: Union["BaseTransformation", "Deserializer"],
) -> str:
    """
    This function is used for uploading the function code in case a UDF type transformation was used (Pandas/Koalas)
    If a transformation was supplied, meaning we're running for at least batch, will use the SaaS adapted
    function to get the presign URL.
    """
    uploaded_artifact_url: str

    # this is done here to avoid cyclic imports
    from qwak.feature_store.data_sources.streaming.kafka.deserialization import (
        Deserializer,
    )
    from qwak.feature_store.feature_sets.transformations.transformations import (
        BaseTransformation,
    )

    if isinstance(artifact_object, BaseTransformation):
        presign_url = get_featureset_presign_url(
            features_manager_client=features_manager_client,
            feature_store_object_name=feature_store_object_name,
            feature_store_object_name_suffix=feature_store_object_name_suffix,
            transformation=artifact_object,
        )
    elif isinstance(artifact_object, Deserializer):
        presign_url = get_data_source_presign_url_v1(
            features_manager_client=features_manager_client,
            data_source_object_name=feature_store_object_name,
            data_source_name_suffix=feature_store_object_name_suffix,
        )
    else:
        raise QwakException(
            f"Got an unsupported artifact type: {type(artifact_object)}"
        )

    uploaded_artifact_url = base_upload_function_code(
        presign_url, functions, feature_module_dir
    )

    return uploaded_artifact_url


def upload_to_s3(presign_url: str, in_memory_zip: bytes, content_type: str) -> str:
    http_response = requests.put(
        presign_url,
        headers={"content-type": content_type},
        data=in_memory_zip,
        timeout=600,
    )
    if 400 <= http_response.status_code < 600:
        raise QwakException(
            f"Error while uploading user function to s3. status code: {http_response.status_code}"
        )

    from urllib.parse import urlparse

    parsed_url = urlparse(presign_url)
    postfix = parsed_url.path
    bucket = parsed_url.hostname.split(".s3.")[0]
    s3_path = f"s3://{bucket}{postfix}"  # noqa: E231
    return s3_path


def base_upload_function_code(
    presign_url: str,
    functions: List[Callable],
    feature_module_dir: Path,
) -> str:
    """
    get presign url and prepare a zip file with the functions code
    and it's module and upload it to clients' s3 bucket
    Args:
        presign_url: presign url
        functions: udf functions
        feature_module_dir: parent directory path of the feature
    Returns:
        Full path to the zip file uploaded
    """
    in_memory_zip = zip_function_with_base_folder(functions, feature_module_dir)
    return upload_to_s3(
        presign_url=presign_url,
        in_memory_zip=in_memory_zip,
        content_type=ZIP_FUNCTION_CONTENT_TYPE,
    )



from abc import ABC
from dataclasses import dataclass

from _qwak_proto.qwak.feature_store.features.aggregation_pb2 import (
    Avg as ProtoAvg,
    BooleanAnd as ProtoBooleanAnd,
    BooleanOr as ProtoBooleanOr,
    Count as ProtoCount,
    LastDistinctN as ProtoLastDistinctN,
    LastN as ProtoLastN,
    Max as ProtoMax,
    Min as ProtoMin,
    Percentile as ProtoPercentile,
    PopulationSTDEV as ProtoPopulationSTDEV,
    PopulationVariance as ProtoPopulationVariance,
    SampleSTDEV as ProtoSampleSTDEV,
    SampleVariance as ProtoSampleVariance,
    Sum as ProtoSum,
)
from qwak.exceptions import QwakException


@dataclass
class BaseAggregate(ABC):
    """
    Base class for Qwak supported aggregations
    """

    def __init__(self, column):
        self._column: str = column
        self._alias_name: str = ""

        self.__post_init__()

    def __post_init__(self):
        if "." in self._column:
            raise QwakException(
                f"Aggregation {self.__repr__()} column {self._column} contains an illegal character '.'"
            )

    @property
    def _key(self):
        raise NotImplementedError

    @property
    def _proto_class(self):
        raise NotImplementedError

    def alias(self, name):
        if "." in name:
            raise QwakException(
                f"Aggregation {self.__repr__()} alias {name} contains an illegal character '.'"
            )
        self._alias_name = name
        return self

    def has_alias(self):
        return bool(self._alias_name)

    def to_proto(self):
        return self._proto_class(field_name=self._column)

    def get_name(self):
        return self._alias_name if self.has_alias() else f"{self._key}_{self._column}"


class SumAggregate(BaseAggregate):
    _key = "sum"
    _proto_class = ProtoSum


class CountAggregate(BaseAggregate):
    _key = "count"
    _proto_class = ProtoCount


class MaxAggregate(BaseAggregate):
    _key = "max"
    _proto_class = ProtoMax


class MinAggregate(BaseAggregate):
    _key = "min"
    _proto_class = ProtoMin


class AvgAggregate(BaseAggregate):
    _key = "avg"
    _proto_class = ProtoAvg


class SampleVarianceAggregate(BaseAggregate):
    _key = "sample_variance"
    _proto_class = ProtoSampleVariance


class PopulationVarianceAggregate(BaseAggregate):
    _key = "population_variance"
    _proto_class = ProtoPopulationVariance


class SampleSTDEVAggregate(BaseAggregate):
    _key = "sample_stdev"
    _proto_class = ProtoSampleSTDEV


class PopulationSTDEVAggregate(BaseAggregate):
    _key = "population_stdev"
    _proto_class = ProtoPopulationSTDEV


class BooleanAndAggregate(BaseAggregate):
    _key = "boolean_and"
    _proto_class = ProtoBooleanAnd


class BooleanOrAggregate(BaseAggregate):
    _key = "boolean_or"
    _proto_class = ProtoBooleanOr


class LastNAggregate(BaseAggregate):
    _key = "last_n"
    _proto_class = ProtoLastN

    def __init__(self, column: str, n: int):
        self.n = n
        super().__init__(column)
        self.__post_init__()

    def __post_init__(self):
        self._validate()
        super().__post_init__()

    def _validate(self):
        if not (type(self.n) is int and self.n > 0):
            raise QwakException("p must be a positive integer")

    def to_proto(self):
        return self._proto_class(field_name=self._column, n=self.n)

    def get_name(self):
        return self._alias_name if self.has_alias() else f"last_{self.n}_{self._column}"


class LastDistinctNAggregate(BaseAggregate):
    _key = "last_distinct_n"
    _proto_class = ProtoLastDistinctN

    def __init__(self, column: str, n: int):
        self.n = n
        super().__init__(column)
        self.__post_init__()

    def __post_init__(self):
        self._validate()
        super().__post_init__()

    def _validate(self):
        if not (type(self.n) is int and self.n > 0):
            raise QwakException("p must be a positive integer")

    def to_proto(self):
        return self._proto_class(field_name=self._column, n=self.n)

    def get_name(self):
        return (
            self._alias_name
            if self.has_alias()
            else f"last_distinct_{self.n}_{self._column}"
        )


class PercentileAggregate(BaseAggregate):
    _key = "percentile"
    _proto_class = ProtoPercentile

    def __init__(self, column: str, p: int):
        self.p = p
        super().__init__(column)
        self.__post_init__()

    def __post_init__(self):
        self._validate()
        super().__post_init__()

    def _validate(self):
        if not (type(self.p) is int and 0 < self.p < 100):
            raise QwakException("p must be an integer between 1 and 99")

    def to_proto(self):
        return self._proto_class(field_name=self._column, p=self.p)

    def get_name(self):
        return self._alias_name if self.has_alias() else f"p{self.p}_{self._column}"


class QwakAggregation:
    """
    Holding all Qwak native supported aggregations. Currently, can be used in Streaming feature sets only.
    """

    @staticmethod
    def sum(column):
        """
        A sum aggregation.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.sum("amount"))\
        >>>     .by_windows("1 day"),
        """
        return SumAggregate(column)

    @staticmethod
    def count(column):
        """
        A count aggregation.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.count("amount"))\
        >>>     .by_windows("1 day"),
        """
        return CountAggregate(column)

    @staticmethod
    def max(column):
        """
        A max aggregation.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.max("amount"))\
        >>>     .by_windows("1 day"),
        """
        return MaxAggregate(column)

    @staticmethod
    def min(column):
        """
        A min aggregation.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.min("amount"))\
        >>>     .by_windows("1 day"),
        """
        return MinAggregate(column)

    @staticmethod
    def avg(column):
        """
        A avarage aggregation.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.avg("amount"))\
        >>>     .by_windows("1 day"),
        """
        return AvgAggregate(column)

    @staticmethod
    def sample_variance(column):
        """
        A sample variance aggregation.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.sample_variance("amount"))\
        >>>     .by_windows("1 day"),
        """
        return SampleVarianceAggregate(column)

    @staticmethod
    def population_variance(column):
        """
        A population variance aggregation.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.population_variance("amount"))\
        >>>     .by_windows("1 day"),
        """
        return PopulationVarianceAggregate(column)

    @staticmethod
    def sample_stdev(column):
        """
        A sample STDEV aggregation.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.sample_stdev("amount"))\
        >>>     .by_windows("1 day"),
        """
        return SampleSTDEVAggregate(column)

    @staticmethod
    def population_stdev(column):
        """
        A population STDEV aggregation

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.population_stdev("amount"))\
        >>>     .by_windows("1 day"),
        """
        return PopulationSTDEVAggregate(column)

    @staticmethod
    def boolean_and(column):
        """
        A BOOLEAN AND aggregation.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.boolean_and("is_fraud"))\
        >>>     .by_windows("1 day"),
        """
        return BooleanAndAggregate(column)

    @staticmethod
    def boolean_or(column):
        """
        A BOOLEAN OR aggregation.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.boolean_or("is_fraud"))\
        >>>     .by_windows("1 day"),
        """
        return BooleanOrAggregate(column)

    @staticmethod
    def last_n(column, n):
        """
        A last_n aggregation

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.last_n("amount", n=10))\
        >>>     .by_windows("1 day"),
        """
        return LastNAggregate(column, n=n)

    @staticmethod
    def last_distinct_n(column, n):
        """
        A last_distinct_n aggregation

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.last_distinct_n("amount", n=10))\
        >>>     .by_windows("1 day"),
        """
        return LastDistinctNAggregate(column, n=n)

    @staticmethod
    def percentile(column, p):
        """
        Calculates a percentile - e.g., p50 (aka median), p90 etc.

        Example:
        >>> from qwak.feature_store.feature_sets.transformations import SparkSqlTransformation
        >>> from qwak.feature_store.feature_sets.transformations import QwakAggregation
        >>>
        >>> SparkSqlTransformation(sql="SELECT id, amount, event_timestamp, offset" \
        >>>                                      "topic, partition FROM transaction_stream")\
        >>>     .aggregate(QwakAggregation.percentile("amount", p=50).alias("median_amount"))\
        >>>     .by_windows("1 day"),
        """
        return PercentileAggregate(column, p=p)



import base64
import json
import socket
from datetime import datetime

import requests
from qwak.clients.administration import AuthenticationClient
from qwak.inner.di_configuration.account import UserAccountConfiguration


def _get_authorization():
    user_account_configuration = UserAccountConfiguration()
    token = (
        AuthenticationClient()
        .authenticate(user_account_configuration.get_user_apikey())
        .access_token
    )
    token_split = token.split(".")
    decoded_token = json.loads(_base64url_decode(token_split[1]).decode("utf-8"))
    token_expiration = datetime.fromtimestamp(decoded_token["exp"])

    return f"Bearer {token}", token_expiration


def _base64url_decode(input):
    rem = len(input) % 4
    if rem > 0:
        input += "=" * (4 - rem)

    return base64.urlsafe_b64decode(input)


class SocketAdapter(requests.adapters.HTTPAdapter):
    def __init__(self, *args, socket_params=None, **kwargs):
        self.socket_params = socket_params
        super().__init__(*args, **kwargs)

    def init_poolmanager(self, *args, **kwargs):
        if self.socket_params:
            kwargs["socket_options"] = self.socket_params
        super().init_poolmanager(*args, **kwargs)


# Configure only TCP attributes that are available in the OS
def validate_socket_config(socket_options):
    config = []
    for line in socket_options:
        if hasattr(socket, line[0]) and hasattr(socket, line[1]):
            config.append((getattr(socket, line[0]), getattr(socket, line[1]), line[2]))
    return config


class RestSession(requests.Session):
    def __init__(self):
        super().__init__()
        self.headers.update({"Content-Type": "application/json"})
        socket_options = [
            ("SOL_SOCKET", "SO_KEEPALIVE", 1),
            ("SOL_TCP", "TCP_KEEPIDLE", 120),
            ("SOL_TCP", "TCP_KEEPINTVL", 75),
            ("SOL_TCP", "TCP_KEEPCNT", 9),
        ]
        socket_options = validate_socket_config(socket_options)
        adapter = SocketAdapter(socket_params=socket_options)
        self.mount("https://", adapter)

    def prepare_request(self, request):
        if "Authorization" not in self.headers:
            self.prepare_request_token()
        else:
            if self.jwt_expiration <= datetime.utcnow():
                self.prepare_request_token()

        return super().prepare_request(request)

    def prepare_request_token(self):
        (
            self.headers["Authorization"],
            self.jwt_expiration,
        ) = _get_authorization()



from dataclasses import dataclass
from typing import Optional

from _qwak_proto.qwak.feature_store.sources.batch_pb2 import (
    AthenaSourceV1 as ProtoAthenaSourceV1,
    AwsAssumeRoleAuthentication as ProtoAwsAssumeRoleAuthentication,
    AwsAuthentication as ProtoAwsAuthentication,
    AwsCredentialsAuthentication as ProtoAwsCredentialsAuthentication,
    BatchSource as ProtoBatchSource,
    DatePartitionColumns as ProtoDatePartitionColumns,
    JdbcSource as ProtoJdbcSource,
    TimeFragmentedPartitionColumns as ProtoTimeFragmentedPartitionColumns,
)
from _qwak_proto.qwak.feature_store.sources.data_source_pb2 import (
    DataSourceSpec as ProtoDataSourceSpec,
)
from qwak.feature_store.data_sources.batch._jdbc import JdbcSource
from qwak.feature_store.data_sources.source_authentication import (
    AwsAssumeRoleAuthentication,
    AwsAuthentication,
    AwsCredentialsAuthentication,
)
from qwak.feature_store.data_sources.time_partition_columns import (
    ColumnRepresentation,
    DatePartitionColumns,
    DayFragmentColumn,
    MonthFragmentColumn,
    TimeFragmentedPartitionColumns,
    TimePartitionColumns,
    YearFragmentColumn,
)


@dataclass
class AthenaSource(JdbcSource):
    aws_region: str = str()
    s3_output_location: str = str()
    aws_authentication: Optional[AwsAuthentication] = None
    time_partition_columns: Optional[TimePartitionColumns] = None
    workgroup: Optional[str] = None

    def _validate(self):
        super()._validate()

        if self.aws_authentication is None:
            raise AttributeError("`aws_authentication` must be set")

        if not self.aws_region:
            raise AttributeError("`aws_region` must be set")

        if not self.s3_output_location and not self.workgroup:
            raise AttributeError(
                "At least one of: `s3_output_location`, `workgroup` must be set"
            )

    def _to_proto(self, artifact_url: Optional[str] = None):
        proto_date_partition_columns = None
        proto_time_fragment_partition_columns = None

        if self.time_partition_columns:
            proto_partition = self.time_partition_columns._to_proto()
            if isinstance(proto_partition, ProtoDatePartitionColumns):
                proto_date_partition_columns = proto_partition
            elif isinstance(proto_partition, ProtoTimeFragmentedPartitionColumns):
                proto_time_fragment_partition_columns = proto_partition
            else:
                raise ValueError(
                    f"Got an unsupported time partition column: {proto_partition}"
                )

        proto_aws_assume_role_authentication = None
        proto_aws_static_credentials_authentication = None

        proto_aws_authentication = self.aws_authentication._to_proto()
        if isinstance(proto_aws_authentication, ProtoAwsAssumeRoleAuthentication):
            proto_aws_assume_role_authentication = proto_aws_authentication
        elif isinstance(proto_aws_authentication, ProtoAwsCredentialsAuthentication):
            proto_aws_static_credentials_authentication = proto_aws_authentication

        proto_auth: AwsAuthentication = ProtoAwsAuthentication(
            aws_assume_role_authentication=proto_aws_assume_role_authentication,
            aws_static_credentials_authentication=proto_aws_static_credentials_authentication,
        )

        return ProtoDataSourceSpec(
            batch_source=ProtoBatchSource(
                name=self.name,
                description=self.description,
                date_created_column=self.date_created_column,
                jdbcSource=ProtoJdbcSource(
                    url=self.url,
                    username_secret_name=self.username_secret_name,
                    password_secret_name=self.password_secret_name,
                    db_table=self.db_table,
                    query=self.query,
                    athenaSource=ProtoAthenaSourceV1(
                        aws_authentication=proto_auth,
                        date_partition_columns=proto_date_partition_columns,
                        time_fragmented_partition_columns=proto_time_fragment_partition_columns,
                        s3_output_location=self.s3_output_location,
                        aws_region=self.aws_region,
                        workgroup=self.workgroup,
                    ),
                ),
            )
        )

    @classmethod
    def _from_proto(cls, proto: ProtoBatchSource):
        proto_jdbc_source: ProtoJdbcSource = proto.jdbcSource
        proto_athena_source: ProtoAthenaSourceV1 = proto_jdbc_source.athenaSource

        aws_authentication: AwsAuthentication = (
            AthenaSource._extract_and_configure_aws_authentication(
                proto_athena_source.aws_authentication
            )
        )

        time_partition_columns: Optional[
            TimePartitionColumns
        ] = AthenaSource._extract_partition_column(proto_athena_source)
        workgroup: Optional[str] = (
            proto_athena_source.workgroup
            if proto_athena_source.HasField("workgroup")
            else None
        )

        return cls(
            name=proto.name,
            date_created_column=proto.date_created_column,
            description=proto.description,
            password_secret_name=proto_jdbc_source.password_secret_name,
            username_secret_name=proto_jdbc_source.username_secret_name,
            db_table=proto_jdbc_source.db_table,
            query=proto_jdbc_source.query,
            aws_authentication=aws_authentication,
            time_partition_columns=time_partition_columns,
            aws_region=proto_athena_source.aws_region,
            s3_output_location=proto_athena_source.s3_output_location,
            workgroup=workgroup,
        )

    @staticmethod
    def _extract_and_configure_aws_authentication(
        proto_aws_authentication: ProtoAwsAuthentication,
    ) -> AwsAuthentication:
        auth_type = proto_aws_authentication.WhichOneof("type")

        if auth_type == "aws_static_credentials_authentication":
            proto_aws_authentication = (
                AthenaSource._extract_and_configure_aws_credentials_auth(
                    proto_aws_authentication.aws_static_credentials_authentication
                )
            )
        elif auth_type == "aws_assume_role_authentication":
            proto_aws_authentication = AthenaSource._extract_aws_assume_role_auth(
                proto_aws_authentication.aws_assume_role_authentication
            )
        else:
            raise ValueError(
                f"Got an unsupported aws authentication method: {proto_aws_authentication}"
            )

        return proto_aws_authentication

    @staticmethod
    def _extract_and_configure_aws_credentials_auth(
        proto_aws_creds: ProtoAwsCredentialsAuthentication,
    ) -> AwsCredentialsAuthentication:
        return AwsCredentialsAuthentication(
            access_key_secret_name=proto_aws_creds.access_key_secret_name,
            secret_key_secret_name=proto_aws_creds.secret_key_secret_name,
        )

    @staticmethod
    def _extract_aws_assume_role_auth(
        proto_aws_assume_role: ProtoAwsAssumeRoleAuthentication,
    ) -> AwsAssumeRoleAuthentication:
        return AwsAssumeRoleAuthentication(
            role_arn=proto_aws_assume_role.role_arn,
        )

    @staticmethod
    def _extract_partition_column(
        proto_athena_source: ProtoAthenaSourceV1,
    ) -> Optional[TimePartitionColumns]:
        if proto_athena_source.HasField("time_partition_columns"):
            partition_cols_type = proto_athena_source.WhichOneof(
                "time_partition_columns"
            )

            if partition_cols_type == "date_partition_columns":
                res = DatePartitionColumns(
                    date_column_name=proto_athena_source.date_partition_columns.date_column_name,
                    date_format=proto_athena_source.date_partition_columns.date_format,
                )
            elif partition_cols_type == "time_fragmented_partition_columns":
                year_rep = AthenaSource._extract_column_representation(
                    proto_athena_source.time_fragmented_partition_columns.year_partition_column
                )

                year_fragment_col = YearFragmentColumn(
                    column_name=proto_athena_source.time_fragmented_partition_columns.year_partition_column.column_name,
                    representation=year_rep,
                )

                month_fragment_col = None
                if proto_athena_source.time_fragmented_partition_columns.HasField(
                    "month_partition_column"
                ):
                    month_rep = AthenaSource._extract_column_representation(
                        proto_athena_source.time_fragmented_partition_columns.month_partition_column
                    )

                    month_fragment_col = MonthFragmentColumn(
                        column_name=proto_athena_source.time_fragmented_partition_columns.month_partition_column.column_name,
                        representation=month_rep,
                    )

                day_fragment_col = None
                if proto_athena_source.time_fragmented_partition_columns.HasField(
                    "day_partition_column"
                ):
                    day_rep = AthenaSource._extract_column_representation(
                        proto_athena_source.time_fragmented_partition_columns.day_partition_column
                    )

                    day_fragment_col = DayFragmentColumn(
                        column_name=proto_athena_source.time_fragmented_partition_columns.day_partition_column.column_name,
                        representation=day_rep,
                    )

                res = TimeFragmentedPartitionColumns(
                    year_partition_column=year_fragment_col,
                    month_partition_column=month_fragment_col,
                    day_partition_column=day_fragment_col,
                )
            else:
                raise ValueError(
                    f"Got an unsupported time partition column: {proto_athena_source}"
                )
        else:
            res = None

        return res

    @staticmethod
    def _extract_column_representation(proto_fragment_column):
        column_rep = proto_fragment_column.WhichOneof("column_representation")

        if column_rep == "numeric_column_representation":
            res = ColumnRepresentation.NumericColumnRepresentation
        elif column_rep == "textual_column_representation":
            res = ColumnRepresentation.TextualColumnRepresentation
        else:
            raise ValueError(f"Unsupported ColumnRepresentation: {column_rep}")

        return res
